@@ -104,7 +104,7 @@ get.e0.convergence.all <- function(sim.dir=file.path(getwd(), 'bayesLife.output'
 }
 
 get.e0.convergence <- function(sim.dir=file.path(getwd(), 'bayesLife.output'), 
-									thin=120, burnin=20000) {
+									thin=225, burnin=10000) {
 	file.name <- file.path(sim.dir, 'diagnostics', paste('bayesLife.convergence_', 
 							thin, '_', burnin, '.rda', sep=''))
 	if(!file.exists(file.name)){
@@ -112,9 +112,9 @@ get.e0.convergence <- function(sim.dir=file.path(getwd(), 'bayesLife.output'),
 					' and thin=', thin, ' does not exist.')
 		return(NULL)
 	}
-	bayesTFR.convergence <- local({load(file.name)
-				  					bayesTFR.convergence})
-	return(bayesTFR.convergence)
+	bayesLife.convergence <- local({load(file.name)
+				  					bayesLife.convergence})
+	return(bayesLife.convergence)
 }
 
 get.e0.parameter.traces <- function(mcmc.list, par.names=e0.parameter.names(), burnin=0,
@@ -230,8 +230,6 @@ summary.bayesLife.mcmc.set <- function(object, country=NULL, chain.id=NULL,
 	
 	cat('\nMCMC parameters estimated for', object$meta$nr.countries, 'countries.')
 	cat('\nHyperparameters estimated using', object$meta$nr.countries.estimation, 'countries.')
-	
-	
 	cat('\n')
 	if(meta.only) {
 		get.iter <- function(x) x$finished.iter
@@ -441,3 +439,6 @@ get.countries.table.bayesLife.mcmc.set <- function(object, ...)
 	return(bayesTFR:::get.countries.table.bayesTFR.mcmc.set(object,...))
 get.countries.table.bayesLife.prediction <- function(object, ...) 
 	return(bayesTFR:::get.countries.table.bayesTFR.prediction(object,...))
+
+get.observed.e0 <- function(country.index, meta, matrix.name='e0.matrix', matrix.name.suppl=matrix.name)
+	return(bayesTFR:::get.observed.tfr(country.index, meta, matrix.name=matrix.name, matrix.name.suppl=matrix.name.suppl))
